:mod:`maec.bundle.bundle_reference` Module
==========================================

.. module:: maec.bundle.bundle_reference

Classes
-------

.. autoclass:: BundleReference
	:show-inheritance:
	:members:



